Learn R Programming

PubBias (version 1.0)

ChisqTest_expect: Chi-square test to test for significant difference between observed and expected number of positive studies (not for end user).

Description

Chi-square test to test for significant difference between observed and expected number of positive studies (not for end user).

Usage

ChisqTest_expect(vec_r_events_control, vec_n_sample_size_control, vec_n_sample_size_treated, OR_hat, n, alpha, vec_pos)

Arguments

vec_r_events_control
an ordered vector of number of events in the untreated group of constituent studies from a meta-analysis.
vec_n_sample_size_control
an ordered vector of the number of participants in the untreated group.
vec_n_sample_size_treated
an ordered vector of the number of participants in the treated group.
alpha
Type-1 error rate.
OR_hat
Summary odds ratio from meta-analysis
n
Number of iterations used to generate constituent study power; suggest use 10,000.
vec_pos
Vector of positive results from constituent studies, returned by test.n.treated funtion.

Value

Vector of p-values for difference between observed and expected number of positive studies from meta-analysis, along with vector of expected values.