Learn R Programming

PubBias (version 1.0)

expected_events: calculate the number of expected events from a study included in a meta-analysis assuming summary effect estimate (OR_hat) is true (not for end user).

Description

calculate the number of expected events from a study included in a meta-analysis assuming summary effect estimate (OR_hat) is true (not for end user).

Usage

expected_events(vec_r_events_control, vec_n_sample_size_control, vec_n_sample_size_treated, OR_hat, n, alpha)

Arguments

vec_r_events_control
an ordered vector of number of events in the untreated group of constituent studies from a meta-analysis.
vec_n_sample_size_control
an ordered vector of the number of participants in the untreated group.
vec_n_sample_size_treated
an ordered vector of the number of participants in the treated group.
alpha
Type-1 error rate.
n
Number of iterations used to generate constituent study power; suggest use 10,000.
OR_hat
Summary odds ratio from meta-analysis

Value

Expected number of events at given alpha level.